@@ -1,4 +1,4 @@
-/* analyt.f -- translated by f2c (version 19991025).
+/* analyt.f -- translated by f2c (version 20020621).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
@@ -115,11 +115,9 @@ struct {
 static integer c__1 = 1;
 static doublereal c_b11 = -1.5;
 
-/* Subroutine */ int analyt_(psum, palpha, pbeta, coord, nat, jja, jjd, iia, 
-	iid, eng)
-doublereal *psum, *palpha, *pbeta, *coord;
-integer *nat, *jja, *jjd, *iia, *iid;
-doublereal *eng;
+/* Subroutine */ int analyt_(doublereal *psum, doublereal *palpha, doublereal 
+	*pbeta, doublereal *coord, integer *nat, integer *jja, integer *jjd, 
+	integer *iia, integer *iid, doublereal *eng)
 {
     /* Initialized data */
 
@@ -130,44 +128,42 @@ doublereal *eng;
     doublereal d__1, d__2, d__3, d__4, d__5, d__6;
 
     /* Builtin functions */
-    integer i_indx();
-    double sqrt();
-    integer s_rsue(), do_uio(), e_rsue();
-    double exp(), pow_dd();
+    integer i_indx(char *, char *, ftnlen, ftnlen);
+    double sqrt(doublereal);
+    integer s_rsue(cilist *), do_uio(integer *, char *, ftnlen), e_rsue(void);
+    double exp(doublereal), pow_dd(doublereal *, doublereal *);
 
     /* Local variables */
-    static doublereal enuc[3];
-    extern /* Subroutine */ int ders_();
-    static doublereal anam1, alph1, alph2, part1, part2, part3;
     static integer i__, j, k, l, m, n;
-    static doublereal alpha;
-    extern /* Subroutine */ int delri_();
-    static integer nbond;
-    static doublereal a0, termk, terml, c1, c2, c3, f3;
+    static doublereal a0, c1, c2, c3, f3;
     static integer i1, j1;
-    static doublereal r0, r2;
-    static logical mindo3;
-    static doublereal aa, bb, dd;
+    static doublereal r0, r2, aa, bb, dd;
     static integer ia;
     static doublereal bi[4], bj[4];
-    static integer jd, ja, id, ka, kg, la, lg, ni, nj, is, i22, ii, ig, lk, 
-	    mn;
+    static integer jd, ja, id, ka, kg, la, lg, i22, ni, nj, ii, is, ig, lk, 
+	    mn, jj, ij;
     static doublereal rr;
-    static integer jj;
-    static doublereal termaa, termab;
-    extern /* Subroutine */ int delmol_();
-    static integer ij, kk;
-    static doublereal termnc;
-    static integer ll;
+    static integer kk, ll, kl, mk, nk, ml, nl;
     static logical am1;
-    static integer kl, mk, nk, istart, jstart;
-    static doublereal dr1;
-    static integer ml, nl;
-    static doublereal eaa[3], eab[3];
+    static doublereal dr1, eaa[3], eab[3];
     static integer iol;
     static doublereal rij;
     static integer isp;
-    static doublereal del1, del2, del3, exp1, exp2;
+    static doublereal del1, del2, del3, exp1, exp2, enuc[3];
+    extern /* Subroutine */ int ders_(integer *, integer *, doublereal *, 
+	    doublereal *, doublereal *, doublereal *, integer *, integer *);
+    static doublereal anam1, alph1, alph2, part1, part2, part3, alpha;
+    extern /* Subroutine */ int delri_(doublereal *, integer *, integer *, 
+	    doublereal *, doublereal *);
+    static integer nbond;
+    static doublereal termk, terml;
+    static logical mindo3;
+    static doublereal termaa, termab;
+    extern /* Subroutine */ int delmol_(doublereal *, integer *, integer *, 
+	    integer *, integer *, integer *, integer *, integer *, integer *, 
+	    integer *, doublereal *, doublereal *, integer *);
+    static doublereal termnc;
+    static integer istart, jstart;
 
     /* Fortran I/O blocks */
     static cilist io___36 = { 0, 2, 0, 0, 0 };
