@@ -1,4 +1,4 @@
-/* bonds.f -- translated by f2c (version 19991025).
+/* bonds.f -- translated by f2c (version 20020621).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
@@ -55,50 +55,54 @@ struct {
 
 static integer c__1 = 1;
 
-/* Subroutine */ int bonds_(p)
-doublereal *p;
+/* Subroutine */ int bonds_(doublereal *p)
 {
     /* System generated locals */
     integer i__1, i__2, i__3, i__4;
     doublereal d__1;
 
     /* Builtin functions */
-    integer i_indx(), s_wsfe(), do_fio(), e_wsfe();
+    integer i_indx(char *, char *, ftnlen, ftnlen), s_wsfe(cilist *), do_fio(
+	    integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static doublereal spna[120], spsa[120];
-    static integer nopn;
-    static doublereal spsq[120], a;
+    static doublereal a;
     static integer i__, j, k, l, m, n;
-    static doublereal v[120], x;
-    extern /* Subroutine */ int dopen_();
-    static doublereal pspin[45150], aa, da;
+    static doublereal v[120], x, aa, da;
     static logical ci;
     static doublereal aq[120];
-    static integer ij;
+    static integer ij, il, kk;
     static doublereal sd[120];
-    static integer ll, kk, il, ih;
+    static integer ll, ih;
     static doublereal fv[120], pm[120];
     static integer mu;
     static doublereal ps[90000]	/* was [300][300] */, sq[120], tq[120], sp[
-	    120], spinab[39600];
-    static integer linear;
-    static doublereal zkappa;
-    extern /* Subroutine */ int vecprt_();
+	    120];
     static logical kci, nci;
-    static doublereal aux[14400]	/* was [120][120] */, sum;
+    static doublereal aux[14400]	/* was [120][120] */, sum, spna[120], 
+	    spsa[120];
+    static integer nopn;
+    static doublereal spsq[120];
+    extern /* Subroutine */ int dopen_(doublereal *, integer *, integer *, 
+	    integer *, integer *, doublereal *);
+    static doublereal pspin[45150];
+    static integer linear;
+    static doublereal spinab[39600], zkappa;
+    extern /* Subroutine */ int vecprt_(doublereal *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___5 = { 0, 6, 0, "(2x,'nelecs nclose nopen nopn',4I5)", 
 	    0 };
     static cilist io___15 = { 0, 6, 0, "(10X,'ROHF ZKAPPA=',F10.5,2I5)", 0 };
     static cilist io___33 = { 0, 6, 0, "(//)", 0 };
-    static cilist io___34 = { 0, 6, 0, "(1X,10X,51('* '),//1X, 10X,'* ',9X,'\
-STATISTICAL POP ULATION ANALYSIS',9X,'* ',//1X,10X,51('* '))", 0 };
+    static cilist io___34 = { 0, 6, 0, "(1X,10X,51('* '),//1X, 10X,'* ',9X,'"
+	    "STATISTICAL POP ULATION ANALYSIS',9X,'* ',//1X,10X,51('* '))", 0 }
+	    ;
     static cilist io___35 = { 0, 6, 0, "(1X//20X,'DEGREES OF BONDING'/)", 0 };
     static cilist io___36 = { 0, 6, 0, "(///)", 0 };
-    static cilist io___37 = { 0, 6, 0, "(1X,5X,'SELF-Q',4X,'ACTIV-Q',3X,'TOT\
-AL-Q',3X,'VALENCE',3X,'FREE-VA',1X,'STAT.PROM',1X,'MULL.PROM'//)", 0 };
+    static cilist io___37 = { 0, 6, 0, "(1X,5X,'SELF-Q',4X,'ACTIV-Q',3X,'TOT"
+	    "AL-Q',3X,'VALENCE',3X,'FREE-VA',1X,'STAT.PROM',1X,'MULL.PROM'//)",
+	     0 };
     static cilist io___38 = { 0, 6, 0, "(1X,I2,7F10.5/)", 0 };
     static cilist io___40 = { 0, 6, 0, "(1X,'CLOSED SHELL'//)", 0 };
     static cilist io___42 = { 0, 6, 0, "(1X,'ROHF'//)", 0 };
@@ -106,15 +110,16 @@ AL-Q',3X,'VALENCE',3X,'FREE-VA',1X,'STAT.PROM',1X,'MULL.PROM'//)", 0 };
     static cilist io___45 = { 0, 6, 0, "(//)", 0 };
     static cilist io___46 = { 0, 6, 0, "(10X,'NALPHA-NBETA= ',F10.5,//)", 0 };
     static cilist io___47 = { 0, 6, 0, "(1X,'OPEN SHELL& UHF CASE'//)", 0 };
-    static cilist io___49 = { 0, 6, 0, "(1X,10X,51('* ')//1X,10X,'* ',9X,'ST\
-ATISTICAL SPIN   POPULATION ANALYSIS',9X,'* ',//1X,10X,51('* '))", 0 };
-    static cilist io___54 = { 0, 6, 0, "(1X//20X,'SELF UNPAIRED AND BOND SPI\
-N POPULATIONS '/)", 0 };
+    static cilist io___49 = { 0, 6, 0, "(1X,10X,51('* ')//1X,10X,'* ',9X,'ST"
+	    "ATISTICAL SPIN   POPULATION ANALYSIS',9X,'* ',//1X,10X,51('* '))",
+	     0 };
+    static cilist io___54 = { 0, 6, 0, "(1X//20X,'SELF UNPAIRED AND BOND SPI"
+	    "N POPULATIONS '/)", 0 };
     static cilist io___55 = { 0, 6, 0, "(//)", 0 };
-    static cilist io___56 = { 0, 6, 0, "(10X,' TOTAL ATOMIC SPIN POPULATIONS\
-'/)", 0 };
-    static cilist io___57 = { 0, 6, 0, "(1X,'ATOM    SELF UNCPLD SPIN    SHA\
-RED UNCPLD SPIN      TOTAL UNCPLD SPIN '///(1X,I3,3F20.5))", 0 };
+    static cilist io___56 = { 0, 6, 0, "(10X,' TOTAL ATOMIC SPIN POPULATIONS"
+	    "'/)", 0 };
+    static cilist io___57 = { 0, 6, 0, "(1X,'ATOM    SELF UNCPLD SPIN    SHA"
+	    "RED UNCPLD SPIN      TOTAL UNCPLD SPIN '///(1X,I3,3F20.5))", 0 };
 
 
 /* COMDECK SIZES */
@@ -471,18 +476,15 @@ L1002:
     return 0;
 } /* bonds_ */
 
-/* Subroutine */ int dopen_(c__, mdim, norbs, ndubl, nsingl, fract)
-doublereal *c__;
-integer *mdim, *norbs, *ndubl, *nsingl;
-doublereal *fract;
+/* Subroutine */ int dopen_(doublereal *c__, integer *mdim, integer *norbs, 
+	integer *ndubl, integer *nsingl, doublereal *fract)
 {
     /* System generated locals */
     integer c_dim1, c_offset, i__1, i__2, i__3;
 
     /* Local variables */
-    static doublereal frac;
     static integer i__, j, k, l, n2, nl1, nu1;
-    static doublereal sum1;
+    static doublereal sum1, frac;
 
 /* COMDECK SIZES */
 /* *********************************************************************** */
