@@ -1,4 +1,4 @@
-/* deriv.f -- translated by f2c (version 19991025).
+/* deriv.f -- translated by f2c (version 20020621).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
@@ -129,8 +129,7 @@ static doublereal c_b70 = 10.;
 static integer c__9 = 9;
 static integer c__6 = 6;
 
-/* Subroutine */ int deriv_(geo, grad)
-doublereal *geo, *grad;
+/* Subroutine */ int deriv_(doublereal *geo, doublereal *grad)
 {
     /* Initialized data */
 
@@ -144,44 +143,48 @@ doublereal *geo, *grad;
     alist al__1;
 
     /* Builtin functions */
-    integer i_indx(), f_open(), f_rew(), s_rsfe(), do_fio(), e_rsfe(), s_wsfe(
-	    ), e_wsfe();
-    /* Subroutine */ int s_stop();
-    integer s_rsle(), do_lio(), e_rsle();
-    double pow_di(), sqrt();
-    integer s_wsle(), e_wsle();
+    integer i_indx(char *, char *, ftnlen, ftnlen), f_open(olist *), f_rew(
+	    alist *), s_rsfe(cilist *), do_fio(integer *, char *, ftnlen), 
+	    e_rsfe(void), s_wsfe(cilist *), e_wsfe(void);
+    /* Subroutine */ int s_stop(char *, ftnlen);
+    integer s_rsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
+	    e_rsle(void);
+    double pow_di(doublereal *, integer *), sqrt(doublereal);
+    integer s_wsle(cilist *), e_wsle(void);
 
     /* Local variables */
+    static integer i__, j;
+    static logical ci;
+    static integer ii, ij, il, jl, kl, ll, kk;
+    static logical aic;
+    extern doublereal dot_(doublereal *, doublereal *, integer *);
+    static logical int__;
+    extern /* Subroutine */ int mxm_(doublereal *, integer *, doublereal *, 
+	    integer *, doublereal *, integer *);
+    static doublereal sum;
+    static logical scf1;
     static char line[80];
     static integer ncol;
     static doublereal xjuc[3], step;
     static logical slow;
-    static integer i__, j, icapa;
+    static integer icapa;
     static logical halfe, debug;
-    extern /* Subroutine */ int dcart_();
+    extern /* Subroutine */ int dcart_(doublereal *, doublereal *);
     static integer iline;
     static logical geook;
     static doublereal grlim;
     static integer ilowa;
     static doublereal gnorm;
-    extern /* Subroutine */ int geout_();
+    extern /* Subroutine */ int geout_(integer *);
     static integer ilowz;
-    static logical ci;
-    static integer ii, ij;
-    static doublereal change[3];
-    static integer il, jl, kl;
-    static doublereal aidref[360];
-    static integer ll, kk, idelta;
-    extern /* Character */ VOID getnam_();
+    static doublereal change[3], aidref[360];
+    static integer idelta;
+    extern /* Character */ VOID getnam_(char *, ftnlen, char *, ftnlen);
     static logical precis, noanci, aifrst;
-    extern /* Subroutine */ int dernvo_(), jcarin_(), gmetry_(), deritr_(), 
-	    symtry_();
-    static logical aic;
-    extern doublereal dot_();
-    static logical int__;
-    extern /* Subroutine */ int mxm_();
-    static doublereal sum;
-    static logical scf1;
+    extern /* Subroutine */ int dernvo_(doublereal *, doublereal *), jcarin_(
+	    doublereal *, doublereal *, doublereal *, logical *, doublereal *,
+	     integer *), gmetry_(doublereal *, doublereal *), deritr_(
+	    doublereal *, doublereal *), symtry_(void);
 
     /* Fortran I/O blocks */
     static cilist io___14 = { 0, 5, 0, "(A)", 0 };
@@ -209,8 +212,8 @@ doublereal *geo, *grad;
     static cilist io___58 = { 0, 6, 0, "(10F8.3)", 0 };
     static cilist io___59 = { 0, 6, 0, "(' ERROR FUNCTION')", 0 };
     static cilist io___60 = { 0, 6, 0, "(10F8.3)", 0 };
-    static cilist io___61 = { 0, 6, 0, "(' COSINE OF SEARCH DIRECTION =',F30\
-.6)", 0 };
+    static cilist io___61 = { 0, 6, 0, "(' COSINE OF SEARCH DIRECTION =',F30"
+	    ".6)", 0 };
 
 
 /* COMDECK SIZES */
@@ -381,8 +384,8 @@ L60:
 		goto L50;
 	    }
 	    s_wsfe(&io___26);
-	    do_fio(&c__1, " AB-INITIO DERIVATIVES IN KCAL/MOL/(ANGSTROM OR R\
-ADIAN)", (ftnlen)55);
+	    do_fio(&c__1, " AB-INITIO DERIVATIVES IN KCAL/MOL/(ANGSTROM OR R"
+		    "ADIAN)", (ftnlen)55);
 	    e_wsfe();
 	    s_wsfe(&io___27);
 	    i__1 = j;
@@ -432,8 +435,8 @@ ADIAN)", (ftnlen)55);
 /* L90: */
 		}
 		s_wsfe(&io___31);
-		do_fio(&c__1, " AB-INITIO DERIVATIVES AFTER SYMMETRY WEIGHTI\
-NG", (ftnlen)47);
+		do_fio(&c__1, " AB-INITIO DERIVATIVES AFTER SYMMETRY WEIGHTI"
+			"NG", (ftnlen)47);
 		e_wsfe();
 		s_wsfe(&io___32);
 		i__1 = geovar_1.nvar;
@@ -607,12 +610,12 @@ NG", (ftnlen)47);
 /*  ERROR LOCATED, BUT CANNOT CORRECT IN THIS RUN */
 
 		    s_wsfe(&io___54);
-		    do_fio(&c__1, " INTERNAL COORDINATE DERIVATIVES DO NOT R\
-EFLECT", (ftnlen)47);
+		    do_fio(&c__1, " INTERNAL COORDINATE DERIVATIVES DO NOT R"
+			    "EFLECT", (ftnlen)47);
 		    do_fio(&c__1, " CARTESIAN COORDINATE DERIVATIVES", (
 			    ftnlen)33);
-		    do_fio(&c__1, " TO CORRECT ERROR, INCREASE DIHEDRAL OF A\
-TOM", (ftnlen)44);
+		    do_fio(&c__1, " TO CORRECT ERROR, INCREASE DIHEDRAL OF A"
+			    "TOM", (ftnlen)44);
 		    do_fio(&c__1, (char *)&geovar_1.loc[(i__ << 1) - 2], (
 			    ftnlen)sizeof(integer));
 		    do_fio(&c__1, " BY 90 DEGREES", (ftnlen)14);
