@@ -1,4 +1,4 @@
-/* wrtkey.f -- translated by f2c (version 19991025).
+/* wrtkey.f -- translated by f2c (version 20020621).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
@@ -23,9 +23,7 @@ struct {
 
 static integer c__1 = 1;
 
-/* Subroutine */ int wrtkey_(keywrd, keywrd_len)
-char *keywrd;
-ftnlen keywrd_len;
+/* Subroutine */ int wrtkey_(char *keywrd, ftnlen keywrd_len)
 {
     /* Initialized data */
 
@@ -35,335 +33,335 @@ ftnlen keywrd_len;
     static logical pm3 = FALSE_;
 
     /* Format strings */
-    static char fmt_210[] = "(\002 *  VECTORS  - FINAL EIGENVECTORS TO BE PR\
-INTED\002)";
-    static char fmt_220[] = "(\002 *  EXTERNAL - USE ATOMIC PARAMETERS FROM \
-THE FOLLOWING \002,\002FILE\002,/15x,a)";
-    static char fmt_230[] = "(\002 *  DENSITY  - FINAL DENSITY MATRIX TO BE \
-PRINTED\002)";
-    static char fmt_240[] = "(\002 *  SPIN     - FINAL UHF SPIN MATRIX TO BE\
- PRINTED\002)";
-    static char fmt_250[] = "(\002 *  DEPVAR=N - SPECIFIED DISTANCE IS\002,f\
-7.4,\002 TIMES BOND LENGTH\002)";
-    static char fmt_260[] = "(\002 *  DEP      - OUTPUT FORTRAN CODE FOR BLO\
-CK-DATA\002)";
-    static char fmt_270[] = "(\002 *  VELOCITY - INPUT STARTING VELOCITIES F\
-OR DRC\002)";
-    static char fmt_378[] = "(\002 *  GREEN    - RUN DANOVICH'S GREEN'S FUNC\
-TION CALCN.\002)";
-    static char fmt_280[] = "(\002 *  TIMES    - TIMES OF VARIOUS STAGES TO \
-BE PRINTED\002)";
-    static char fmt_290[] = "(\002 *  PARASOK  - USE SOME MNDO PARAMETERS IN\
- AN AM1 CALCULA\002,\002TION\002)";
-    static char fmt_300[] = "(\002 *  NODIIS   - DO NOT USE GDIIS GEOMETRY O\
-PTIMIZER\002)";
-    static char fmt_310[] = "(\002 *  BONDS    - FINAL BOND-ORDER MATRIX TO \
-BE PRINTED\002)";
-    static char fmt_320[] = "(\002 *  GEO-OK   - OVERRIDE INTERATOMIC DISTAN\
-CE CHECK\002)";
-    static char fmt_330[] = "(\002 *  FOCK     - LAST FOCK MATRIX TO BE PRIN\
-TED\002)";
-    static char fmt_340[] = "(\002 *  LARGE    - EXPANDED OUTPUT TO BE PRINT\
-ED\002)";
-    static char fmt_350[] = "(\002 *   K=      - BRILLOUIN ZONE STRUCTURE TO\
- BE CALCULATED\002)";
-    static char fmt_360[] = "(\002 *  NOLOG    - SUPPRESS LOG FILE TRAIL, WH\
-ERE POSSIBLE\002)";
-    static char fmt_370[] = "(\002 *  AIGIN    - GEOMETRY MUST BE IN GAUSSIA\
-N FORMAT\002)";
-    static char fmt_380[] = "(\002 *  AIGOUT   - IN ARC FILE, INCLUDE AB-INI\
-TIO GEOMETRY\002)";
-    static char fmt_390[] = "(\002 *  AIDER    - READ IN AB INITIO DERIVATIV\
-ES\002)";
-    static char fmt_400[] = "(\002 *  S1978    - 1978 SULFUR PARAMETERS TO B\
-E USED\002)";
-    static char fmt_410[] = "(\002 *  SI1978   - 1978 SILICON PARAMETERS TO \
-BE USED\002)";
-    static char fmt_420[] = "(\002 *  GRAPH    - GENERATE FILE FOR GRAPHIC\
-S\002)";
-    static char fmt_440[] = "(\002 *  NOANCI   - DO NOT USE ANALYTICAL C.I. \
-DERIVATIVES\002)";
-    static char fmt_430[] = "(\002 *  1ELECTRON- FINAL ONE-ELECTRON MATRIX T\
-O BE PRINTED\002)";
-    static char fmt_470[] = "(\002 *  SETUP    - EXTRA KEYWORDS TO BE READ F\
-ROM FILE SETUP\002)";
-    static char fmt_460[] = "(\002 *  NOMM     - DO NOT MAKE MM CORRECTION T\
-O CONH BARRIER\002)";
-    static char fmt_480[] = "(\002 *  MMOK     - APPLY MM CORRECTION TO CONH\
- BARRIER\002)";
-    static char fmt_490[] = "(\002 *  INTERP   - PRINT DETAILS OF CAMP-KING \
-CONVERGER\002)";
-    static char fmt_450[] = "(\002 *  ESR      - RHF SPIN DENSITY CALCULATIO\
-N REQUESTED\002)";
-    static char fmt_500[] = "(\002 *  DFP      - USE DAVIDON FLETCHER POWELL\
- OPTIMIZER\002)";
-    static char fmt_510[] = "(\002 *  ANALYT   - USE ANALYTIC DERIVATIVES\
- \002)";
-    static char fmt_520[] = "(\002 *  MECI     - M.E.C.I. WORKING TO BE PRIN\
-TED\002)";
-    static char fmt_560[] = "(\002 *  LOCALIZE - LOCALIZED ORBITALS TO BE PR\
-INTED\002)";
-    static char fmt_570[] = "(\002 *  MULLIK   - THE MULLIKEN ANALYSIS TO BE\
- PERFORMED\002)";
-    static char fmt_580[] = "(\002 *   XYZ     - CARTESIAN COORDINATE SYSTEM\
- TO BE USED\002)";
-    static char fmt_590[] = "(\002 *   PI      - BONDS MATRIX, SPLIT INTO SI\
-GMA-PI-DELL\002,\002 COMPONENTS, TO BE PRINTED\002)";
-    static char fmt_600[] = "(\002 *  ECHO     - ALL INPUT DATA TO BE ECHOED\
- BEFORE RUN\002)";
-    static char fmt_910[] = "(\002 *  SINGLET  - SPIN STATE DEFINED AS A SIN\
-GLET\002)";
-    static char fmt_920[] = "(\002 *  DOUBLET  - SPIN STATE DEFINED AS A DOU\
-BLET\002)";
-    static char fmt_940[] = "(\002 *  QUARTET  - SPIN STATE DEFINED AS A QUA\
-RTET\002)";
-    static char fmt_950[] = "(\002 *  QUINTET  - SPIN STATE DEFINED AS A QUI\
-NTET\002)";
-    static char fmt_960[] = "(\002 *  SEXTET   - SPIN STATE DEFINED AS A SEX\
-TET\002)";
-    static char fmt_610[] = "(\002 *  H-PRIOR  - HEAT OF FORMATION TAKES PRI\
-ORITY IN DRC\002)";
-    static char fmt_620[] = "(\002 *  X-PRIOR  - GEOMETRY CHANGES TAKE PRIOR\
-ITY IN DRC\002)";
-    static char fmt_630[] = "(\002 *  T-PRIOR  - TIME TAKES PRIORITY IN DR\
-C\002)";
-    static char fmt_650[] = "(\002 *  COMPFG   - PRINT HEAT OF FORMATION CAL\
-C'D IN COMPFG\002)";
-    static char fmt_640[] = "(\002 *  POLAR    - CALCULATE FIRST, SECOND AND\
- THIRD-ORDER\002,\002 POLARIZABILITIES\002)";
+    static char fmt_210[] = "(\002 *  VECTORS  - FINAL EIGENVECTORS TO BE PR"
+	    "INTED\002)";
+    static char fmt_220[] = "(\002 *  EXTERNAL - USE ATOMIC PARAMETERS FROM "
+	    "THE FOLLOWING \002,\002FILE\002,/15x,a)";
+    static char fmt_230[] = "(\002 *  DENSITY  - FINAL DENSITY MATRIX TO BE "
+	    "PRINTED\002)";
+    static char fmt_240[] = "(\002 *  SPIN     - FINAL UHF SPIN MATRIX TO BE"
+	    " PRINTED\002)";
+    static char fmt_250[] = "(\002 *  DEPVAR=N - SPECIFIED DISTANCE IS\002,f"
+	    "7.4,\002 TIMES BOND LENGTH\002)";
+    static char fmt_260[] = "(\002 *  DEP      - OUTPUT FORTRAN CODE FOR BLO"
+	    "CK-DATA\002)";
+    static char fmt_270[] = "(\002 *  VELOCITY - INPUT STARTING VELOCITIES F"
+	    "OR DRC\002)";
+    static char fmt_378[] = "(\002 *  GREEN    - RUN DANOVICH'S GREEN'S FUNC"
+	    "TION CALCN.\002)";
+    static char fmt_280[] = "(\002 *  TIMES    - TIMES OF VARIOUS STAGES TO "
+	    "BE PRINTED\002)";
+    static char fmt_290[] = "(\002 *  PARASOK  - USE SOME MNDO PARAMETERS IN"
+	    " AN AM1 CALCULA\002,\002TION\002)";
+    static char fmt_300[] = "(\002 *  NODIIS   - DO NOT USE GDIIS GEOMETRY O"
+	    "PTIMIZER\002)";
+    static char fmt_310[] = "(\002 *  BONDS    - FINAL BOND-ORDER MATRIX TO "
+	    "BE PRINTED\002)";
+    static char fmt_320[] = "(\002 *  GEO-OK   - OVERRIDE INTERATOMIC DISTAN"
+	    "CE CHECK\002)";
+    static char fmt_330[] = "(\002 *  FOCK     - LAST FOCK MATRIX TO BE PRIN"
+	    "TED\002)";
+    static char fmt_340[] = "(\002 *  LARGE    - EXPANDED OUTPUT TO BE PRINT"
+	    "ED\002)";
+    static char fmt_350[] = "(\002 *   K=      - BRILLOUIN ZONE STRUCTURE TO"
+	    " BE CALCULATED\002)";
+    static char fmt_360[] = "(\002 *  NOLOG    - SUPPRESS LOG FILE TRAIL, WH"
+	    "ERE POSSIBLE\002)";
+    static char fmt_370[] = "(\002 *  AIGIN    - GEOMETRY MUST BE IN GAUSSIA"
+	    "N FORMAT\002)";
+    static char fmt_380[] = "(\002 *  AIGOUT   - IN ARC FILE, INCLUDE AB-INI"
+	    "TIO GEOMETRY\002)";
+    static char fmt_390[] = "(\002 *  AIDER    - READ IN AB INITIO DERIVATIV"
+	    "ES\002)";
+    static char fmt_400[] = "(\002 *  S1978    - 1978 SULFUR PARAMETERS TO B"
+	    "E USED\002)";
+    static char fmt_410[] = "(\002 *  SI1978   - 1978 SILICON PARAMETERS TO "
+	    "BE USED\002)";
+    static char fmt_420[] = "(\002 *  GRAPH    - GENERATE FILE FOR GRAPHIC"
+	    "S\002)";
+    static char fmt_440[] = "(\002 *  NOANCI   - DO NOT USE ANALYTICAL C.I. "
+	    "DERIVATIVES\002)";
+    static char fmt_430[] = "(\002 *  1ELECTRON- FINAL ONE-ELECTRON MATRIX T"
+	    "O BE PRINTED\002)";
+    static char fmt_470[] = "(\002 *  SETUP    - EXTRA KEYWORDS TO BE READ F"
+	    "ROM FILE SETUP\002)";
+    static char fmt_460[] = "(\002 *  NOMM     - DO NOT MAKE MM CORRECTION T"
+	    "O CONH BARRIER\002)";
+    static char fmt_480[] = "(\002 *  MMOK     - APPLY MM CORRECTION TO CONH"
+	    " BARRIER\002)";
+    static char fmt_490[] = "(\002 *  INTERP   - PRINT DETAILS OF CAMP-KING "
+	    "CONVERGER\002)";
+    static char fmt_450[] = "(\002 *  ESR      - RHF SPIN DENSITY CALCULATIO"
+	    "N REQUESTED\002)";
+    static char fmt_500[] = "(\002 *  DFP      - USE DAVIDON FLETCHER POWELL"
+	    " OPTIMIZER\002)";
+    static char fmt_510[] = "(\002 *  ANALYT   - USE ANALYTIC DERIVATIVES"
+	    " \002)";
+    static char fmt_520[] = "(\002 *  MECI     - M.E.C.I. WORKING TO BE PRIN"
+	    "TED\002)";
+    static char fmt_560[] = "(\002 *  LOCALIZE - LOCALIZED ORBITALS TO BE PR"
+	    "INTED\002)";
+    static char fmt_570[] = "(\002 *  MULLIK   - THE MULLIKEN ANALYSIS TO BE"
+	    " PERFORMED\002)";
+    static char fmt_580[] = "(\002 *   XYZ     - CARTESIAN COORDINATE SYSTEM"
+	    " TO BE USED\002)";
+    static char fmt_590[] = "(\002 *   PI      - BONDS MATRIX, SPLIT INTO SI"
+	    "GMA-PI-DELL\002,\002 COMPONENTS, TO BE PRINTED\002)";
+    static char fmt_600[] = "(\002 *  ECHO     - ALL INPUT DATA TO BE ECHOED"
+	    " BEFORE RUN\002)";
+    static char fmt_910[] = "(\002 *  SINGLET  - SPIN STATE DEFINED AS A SIN"
+	    "GLET\002)";
+    static char fmt_920[] = "(\002 *  DOUBLET  - SPIN STATE DEFINED AS A DOU"
+	    "BLET\002)";
+    static char fmt_940[] = "(\002 *  QUARTET  - SPIN STATE DEFINED AS A QUA"
+	    "RTET\002)";
+    static char fmt_950[] = "(\002 *  QUINTET  - SPIN STATE DEFINED AS A QUI"
+	    "NTET\002)";
+    static char fmt_960[] = "(\002 *  SEXTET   - SPIN STATE DEFINED AS A SEX"
+	    "TET\002)";
+    static char fmt_610[] = "(\002 *  H-PRIOR  - HEAT OF FORMATION TAKES PRI"
+	    "ORITY IN DRC\002)";
+    static char fmt_620[] = "(\002 *  X-PRIOR  - GEOMETRY CHANGES TAKE PRIOR"
+	    "ITY IN DRC\002)";
+    static char fmt_630[] = "(\002 *  T-PRIOR  - TIME TAKES PRIORITY IN DR"
+	    "C\002)";
+    static char fmt_650[] = "(\002 *  COMPFG   - PRINT HEAT OF FORMATION CAL"
+	    "C'D IN COMPFG\002)";
+    static char fmt_640[] = "(\002 *  POLAR    - CALCULATE FIRST, SECOND AND"
+	    " THIRD-ORDER\002,\002 POLARIZABILITIES\002)";
     static char fmt_660[] = "(\002 *  DEBUG    - DEBUG OPTION TURNED ON\002)";
     static char fmt_670[] = "(\002 *  RESTART  - CALCULATION RESTARTED\002)";
-    static char fmt_680[] = "(\002 *  ESP      - ELECTROSTATIC POTENTIAL CAL\
-CULATION\002)";
+    static char fmt_680[] = "(\002 *  ESP      - ELECTROSTATIC POTENTIAL CAL"
+	    "CULATION\002)";
     static char fmt_690[] = "(\002 *  NSURF    - NUMBER OF LAYERS\002)";
-    static char fmt_700[] = "(\002 *  SCALE    - SCALING FACTOR FOR VAN DER \
-WAALS DISTANCE\002)";
-    static char fmt_710[] = "(\002 *  SCINCR   - INCREMENT BETWEEN LAYERS\
-\002)";
-    static char fmt_720[] = "(\002 *  SLOPE    - SLOPE - USED TO SCALE MNDO \
-ESP CHARGES\002)";
-    static char fmt_730[] = "(\002 *  DIPOLE   - FIT THE ESP TO THE CALCULAT\
-ED DIPOLE\002)";
-    static char fmt_740[] = "(\002 *  DIPX     - X COMPONENT OF DIPOLE TO BE\
- FIT\002)";
-    static char fmt_750[] = "(\002 *  DIPY     - Y COMPONENT OF DIPOLE TO BE\
- FIT\002)";
-    static char fmt_760[] = "(\002 *  DIPZ     - Z COMPONENT OF DIPOLE TO BE\
- FIT\002)";
+    static char fmt_700[] = "(\002 *  SCALE    - SCALING FACTOR FOR VAN DER "
+	    "WAALS DISTANCE\002)";
+    static char fmt_710[] = "(\002 *  SCINCR   - INCREMENT BETWEEN LAYERS"
+	    "\002)";
+    static char fmt_720[] = "(\002 *  SLOPE    - SLOPE - USED TO SCALE MNDO "
+	    "ESP CHARGES\002)";
+    static char fmt_730[] = "(\002 *  DIPOLE   - FIT THE ESP TO THE CALCULAT"
+	    "ED DIPOLE\002)";
+    static char fmt_740[] = "(\002 *  DIPX     - X COMPONENT OF DIPOLE TO BE"
+	    " FIT\002)";
+    static char fmt_750[] = "(\002 *  DIPY     - Y COMPONENT OF DIPOLE TO BE"
+	    " FIT\002)";
+    static char fmt_760[] = "(\002 *  DIPZ     - Z COMPONENT OF DIPOLE TO BE"
+	    " FIT\002)";
     static char fmt_770[] = "(\002 *  CONNOLLY - USE CONNOLLY SURFACE\002)";
-    static char fmt_780[] = "(\002 *  ESPRST   - RESTART OF ELECTRIC POTENTI\
-AL CALCULATION\002)";
-    static char fmt_790[] = "(\002 *  POTWRT   - WRITE OUT ELECTRIC POT. DAT\
-A TO FILE 21\002)";
+    static char fmt_780[] = "(\002 *  ESPRST   - RESTART OF ELECTRIC POTENTI"
+	    "AL CALCULATION\002)";
+    static char fmt_790[] = "(\002 *  POTWRT   - WRITE OUT ELECTRIC POT. DAT"
+	    "A TO FILE 21\002)";
     static char fmt_800[] = "(\002 *  WILLIAMS - USE WILLIAMS SURFACE\002)";
-    static char fmt_810[] = "(\002 *  SYMAVG   - AVERAGE SYMMETRY EQUIVALENT\
- ESP CHARGES\002)";
-    static char fmt_820[] = "(\002 *  STO3G    - DEORTHOGONALIZE ORBITALS IN\
- STO-3G BASIS\002)";
-    static char fmt_90[] = "(\002 *  IUPD=    - HESSIAN WILL NOT BE UPDATE\
-D\002)";
-    static char fmt_100[] = "(\002 *  IUPD=    - HESSIAN WILL BE UPDATED USI\
-NG POWELL\002)";
-    static char fmt_110[] = "(\002 *  IUPD=    - HESSIAN WILL BE UPDATED USI\
-NG BFGS\002)";
-    static char fmt_120[] = "(\002 *  HESS=    - DIAGONAL HESSIAN USED AS IN\
-ITIAL GUESS\002)";
-    static char fmt_130[] = "(\002 *  HESS=    - INITIAL HESSIAN WILL BE CAL\
-CULATED\002)";
-    static char fmt_140[] = "(\002 *  HESS=    - INITIAL HESSIAN READ FROM D\
-ISK\002)";
-    static char fmt_150[] = "(\002 *  HESS=    - INITIAL HESSIAN READ FROM I\
-NPUT\002)";
-    static char fmt_160[] = "(\002 *  MODE=    - FOLLOW HESSIAN MODE\002,i3\
-,\002 TOWARD TS\002)";
-    static char fmt_170[] = "(\002 *  RECALC=  - DO\002,i4,\002 CYCLES BETWE\
-EN HESSIAN RECALC\002)";
-    static char fmt_180[] = "(\002 *  DMAX=    - TAKE MAXIMUM STEPSIZE OF\
-\002,f5.3,\002 ANG/RAD\002)";
-    static char fmt_190[] = "(\002 *  MS=      - IN MECI, MAGNETIC COMPONENT\
- OF SPIN =\002,i3)";
-    static char fmt_200[] = "(\002 *  PRNT     - EXTRA PRINTING IN EF ROUT\
-INE\002)";
-    static char fmt_830[] = "(\002 *  IRC=N    - INTRINSIC REACTION COORDINA\
-TE\002,i3,\002 DEFINED\002)";
-    static char fmt_840[] = "(\002 *  IRC      - INTRINSIC REACTION COORDINA\
-TE CALCULATION\002)";
-    static char fmt_850[] = "(3(\002 *\002,/),\002 *\002,15x,\002  CHARGE ON\
- SYSTEM =\002,i3,3(/,\002 *\002))";
-    static char fmt_860[] = "(\002 *  GRADIENTS- ALL GRADIENTS TO BE PRINTE\
-D\002)";
-    static char fmt_870[] = "(\002 *  UHF      - UNRESTRICTED HARTREE-FOCK C\
-ALCULATION\002)";
-    static char fmt_890[] = "(\002 *  BIRADICAL- SYSTEM HAS TWO UNPAIRED ELE\
-CTRONS\002)";
-    static char fmt_900[] = "(\002 *  EXCITED  - FIRST EXCITED STATE IS TO B\
-E OPTIMIZED\002)";
-    static char fmt_930[] = "(\002 *  TRIPLET  - SPIN STATE DEFINED AS A TRI\
-PLET\002)";
-    static char fmt_970[] = "(\002 *  SYMMETRY - SYMMETRY CONDITIONS TO BE I\
-MPOSED\002)";
-    static char fmt_971[] = "(\002 *  GROUP    - FREQUENCIES TO BE SYMMETRIZ\
-ED\002)";
+    static char fmt_810[] = "(\002 *  SYMAVG   - AVERAGE SYMMETRY EQUIVALENT"
+	    " ESP CHARGES\002)";
+    static char fmt_820[] = "(\002 *  STO3G    - DEORTHOGONALIZE ORBITALS IN"
+	    " STO-3G BASIS\002)";
+    static char fmt_90[] = "(\002 *  IUPD=    - HESSIAN WILL NOT BE UPDATE"
+	    "D\002)";
+    static char fmt_100[] = "(\002 *  IUPD=    - HESSIAN WILL BE UPDATED USI"
+	    "NG POWELL\002)";
+    static char fmt_110[] = "(\002 *  IUPD=    - HESSIAN WILL BE UPDATED USI"
+	    "NG BFGS\002)";
+    static char fmt_120[] = "(\002 *  HESS=    - DIAGONAL HESSIAN USED AS IN"
+	    "ITIAL GUESS\002)";
+    static char fmt_130[] = "(\002 *  HESS=    - INITIAL HESSIAN WILL BE CAL"
+	    "CULATED\002)";
+    static char fmt_140[] = "(\002 *  HESS=    - INITIAL HESSIAN READ FROM D"
+	    "ISK\002)";
+    static char fmt_150[] = "(\002 *  HESS=    - INITIAL HESSIAN READ FROM I"
+	    "NPUT\002)";
+    static char fmt_160[] = "(\002 *  MODE=    - FOLLOW HESSIAN MODE\002,i3"
+	    ",\002 TOWARD TS\002)";
+    static char fmt_170[] = "(\002 *  RECALC=  - DO\002,i4,\002 CYCLES BETWE"
+	    "EN HESSIAN RECALC\002)";
+    static char fmt_180[] = "(\002 *  DMAX=    - TAKE MAXIMUM STEPSIZE OF"
+	    "\002,f5.3,\002 ANG/RAD\002)";
+    static char fmt_190[] = "(\002 *  MS=      - IN MECI, MAGNETIC COMPONENT"
+	    " OF SPIN =\002,i3)";
+    static char fmt_200[] = "(\002 *  PRNT     - EXTRA PRINTING IN EF ROUT"
+	    "INE\002)";
+    static char fmt_830[] = "(\002 *  IRC=N    - INTRINSIC REACTION COORDINA"
+	    "TE\002,i3,\002 DEFINED\002)";
+    static char fmt_840[] = "(\002 *  IRC      - INTRINSIC REACTION COORDINA"
+	    "TE CALCULATION\002)";
+    static char fmt_850[] = "(3(\002 *\002,/),\002 *\002,15x,\002  CHARGE ON"
+	    " SYSTEM =\002,i3,3(/,\002 *\002))";
+    static char fmt_860[] = "(\002 *  GRADIENTS- ALL GRADIENTS TO BE PRINTE"
+	    "D\002)";
+    static char fmt_870[] = "(\002 *  UHF      - UNRESTRICTED HARTREE-FOCK C"
+	    "ALCULATION\002)";
+    static char fmt_890[] = "(\002 *  BIRADICAL- SYSTEM HAS TWO UNPAIRED ELE"
+	    "CTRONS\002)";
+    static char fmt_900[] = "(\002 *  EXCITED  - FIRST EXCITED STATE IS TO B"
+	    "E OPTIMIZED\002)";
+    static char fmt_930[] = "(\002 *  TRIPLET  - SPIN STATE DEFINED AS A TRI"
+	    "PLET\002)";
+    static char fmt_970[] = "(\002 *  SYMMETRY - SYMMETRY CONDITIONS TO BE I"
+	    "MPOSED\002)";
+    static char fmt_971[] = "(\002 *  GROUP    - FREQUENCIES TO BE SYMMETRIZ"
+	    "ED\002)";
     static char fmt_972[] = "(\002 *  RMAT     - PRINT R MATRICES\002)";
-    static char fmt_973[] = "(\002 *  IPO      - PRINT PERMUTATION OPERATO\
-R\002)";
-    static char fmt_974[] = "(\002 *  NODEGEN  - DO NOT COLLAPSE DEGENERATE \
-FREQUENCIES\002)";
-    static char fmt_990[] = "(\002 *  OPEN(N,N)- THERE ARE\002,i2,\002 ELECT\
-RONS IN\002,i2,\002 LEVELS\002)";
-    static char fmt_980[] = "(\002 *  MICROS=N -\002,i4,\002 MICROSTATES TO \
-BE SUPPLIED FOR C.I.\002)";
-    static char fmt_540[] = "(\002 *  DRC=     - HALF-LIFE FOR KINETIC ENERG\
-Y LOSS =\002,f9.2,\002 * 10**(-15) SECONDS\002)";
-    static char fmt_530[] = "(\002 *  DRC      - DYNAMIC REACTION COORDINATE\
- CALCULATION\002)";
-    static char fmt_550[] = "(\002 *  KINETIC= - \002,f9.3,\002 KCAL KINETIC\
- ENERGY ADDED TO DRC\002)";
-    static char fmt_1000[] = "(\002 *   T=      - A TIME OF\002,f8.1,\002\
- \002,a7,\002 REQUESTED\002)";
-    static char fmt_1010[] = "(\002 *   T=      - A TIME OF\002,g11.3,\002\
- \002,a7,\002 REQUESTED\002)";
-    static char fmt_1020[] = "(\002 *  DUMP=N   - RESTART FILE WRITTEN EVER\
-Y\002,f8.1,\002 \002,a7)";
-    static char fmt_1030[] = "(\002 *  DUMP=N   - RESTART FILE WRITTEN EVER\
-Y\002,g11.3,\002 \002,a7)";
-    static char fmt_1040[] = "(\002 *  1SCF     - DO 1 SCF AND THEN STOP \
-\002)";
-    static char fmt_1060[] = "(\002 * C.I.=(N,M)-\002,i2,\002 DOUBLY FILLED \
-LEVELS USED IN A \002,/,\002 *             C.I. INVOLVING \002,i2,\002 M.O.'S\
-\002)";
-    static char fmt_1050[] = "(\002 *  C.I.=N   -\002,i2,\002 M.O.S TO BE US\
-ED IN C.I.\002)";
-    static char fmt_1070[] = "(\002 *  FORCE    - FORCE CALCULATION SPECIF\
-IED\002)";
-    static char fmt_70[] = "(\002 *  EF       - USE EF ROUTINE FOR MINIMUM S\
-EARCH\002)";
-    static char fmt_80[] = "(\002 *  TS       - USE EF ROUTINE FOR TS SEARC\
-H\002)";
-    static char fmt_1080[] = "(\002 *  MINDO/3  - THE MINDO/3 HAMILTONIAN TO\
- BE USED\002)";
-    static char fmt_1090[] = "(\002 *  AM1      - THE AM1 HAMILTONIAN TO BE \
-USED\002)";
-    static char fmt_1100[] = "(\002 *  PM3      - THE PM3 HAMILTONIAN TO BE \
-USED\002)";
-    static char fmt_1120[] = "(\002 *  OLDGEO   - PREVIOUS GEOMETRY TO BE US\
-ED\002)";
-    static char fmt_1110[] = "(\002 *  PRECISE  - CRITERIA TO BE INCREASED B\
-Y 100 TIMES\002)";
-    static char fmt_1130[] = "(\002 *  NOINTER  - INTERATOMIC DISTANCES NOT \
-TO BE PRINTED\002)";
-    static char fmt_1140[] = "(\002 *  ISOTOPE  - FORCE MATRIX WRITTEN TO DI\
-SK (CHAN. 9 )\002)";
-    static char fmt_1150[] = "(\002 *  DENOUT   - DENSITY MATRIX OUTPUT ON C\
-HANNEL 10\002)";
-    static char fmt_1160[] = "(\002 *  SHIFT    - A DAMPING FACTOR OF\002,f8\
-.2,\002 DEFINED\002)";
-    static char fmt_1170[] = "(\002 *  OLDENS   - INITIAL DENSITY MATRIX REA\
-D OF DISK\002)";
-    static char fmt_1180[] = "(\002 *  SCFCRT   - DEFAULT SCF CRITERION REPL\
-ACED BY\002,g12.3)";
-    static char fmt_1190[] = "(\002 *  ENPART   - ENERGY TO BE PARTITIONED I\
-NTO COMPONENTS\002)";
-    static char fmt_1200[] = "(\002 *  NOXYZ    - CARTESIAN COORDINATES NOT \
-TO BE PRINTED\002)";
-    static char fmt_1210[] = "(\002 *  SIGMA    - GEOMETRY TO BE OPTIMIZED U\
-SING SIGMA.\002)";
-    static char fmt_1220[] = "(\002 *  NLLSQ    - GRADIENTS TO BE MINIMIZED \
-USING NLLSQ.\002)";
-    static char fmt_1230[] = "(\002 *  ROOT     - IN A C.I. CALCULATION, R\
-OOT\002,i2,\002 TO BE OPTIMIZED.\002)";
-    static char fmt_1250[] = "(\002 *  TRANS=   - \002,i4,\002 VIBRATIONS AR\
-E TO BE DELETED FROM\002,\002 THE THERMO CALCULATION\002)";
-    static char fmt_1240[] = "(\002 *  TRANS    - THE REACTION VIBRATION TO \
-BE DELETED FROM\002,\002 THE THERMO CALCULATION\002)";
-    static char fmt_1260[] = "(\002 *  SADDLE   - TRANSITION STATE TO BE OPT\
-IMIZED\002)";
-    static char fmt_1270[] = "(\002 *   LET     - OVERRIDE SOME SAFETY CHE\
-CKS\002)";
-    static char fmt_1280[] = "(\002 *  COMPFG   - PRINT HEAT OF FORMATION CA\
-LC'D IN COMPFG\002)";
-    static char fmt_1290[] = "(\002 *  GNORM=   - EXIT WHEN GRADIENT NORM DR\
-OPS BELOW \002,g8.3)";
-    static char fmt_1300[] = "(\002 *  PULAY    - PULAY'S METHOD TO BE USED \
-IN SCF\002)";
-    static char fmt_1310[] = "(\002 *  STEP1    - FIRST  STEP-SIZE IN GRID \
-=\002,f7.2)";
-    static char fmt_1320[] = "(\002 *  STEP2    - SECOND STEP-SIZE IN GRID \
-=\002,f7.2)";
-    static char fmt_1500[] = "(\002 *  STEP     - STEP-SIZE IN PATH=\002,f7.\
-3)";
-    static char fmt_1330[] = "(\002 *  POINT1   - NUMBER OF ROWS IN GRID \
-=\002,i3)";
-    static char fmt_1340[] = "(\002 *  POINT2   - NUMBER OF COLUMNS IN GRI\
-D =\002,i3)";
+    static char fmt_973[] = "(\002 *  IPO      - PRINT PERMUTATION OPERATO"
+	    "R\002)";
+    static char fmt_974[] = "(\002 *  NODEGEN  - DO NOT COLLAPSE DEGENERATE "
+	    "FREQUENCIES\002)";
+    static char fmt_990[] = "(\002 *  OPEN(N,N)- THERE ARE\002,i2,\002 ELECT"
+	    "RONS IN\002,i2,\002 LEVELS\002)";
+    static char fmt_980[] = "(\002 *  MICROS=N -\002,i4,\002 MICROSTATES TO "
+	    "BE SUPPLIED FOR C.I.\002)";
+    static char fmt_540[] = "(\002 *  DRC=     - HALF-LIFE FOR KINETIC ENERG"
+	    "Y LOSS =\002,f9.2,\002 * 10**(-15) SECONDS\002)";
+    static char fmt_530[] = "(\002 *  DRC      - DYNAMIC REACTION COORDINATE"
+	    " CALCULATION\002)";
+    static char fmt_550[] = "(\002 *  KINETIC= - \002,f9.3,\002 KCAL KINETIC"
+	    " ENERGY ADDED TO DRC\002)";
+    static char fmt_1000[] = "(\002 *   T=      - A TIME OF\002,f8.1,\002"
+	    " \002,a7,\002 REQUESTED\002)";
+    static char fmt_1010[] = "(\002 *   T=      - A TIME OF\002,g11.3,\002"
+	    " \002,a7,\002 REQUESTED\002)";
+    static char fmt_1020[] = "(\002 *  DUMP=N   - RESTART FILE WRITTEN EVER"
+	    "Y\002,f8.1,\002 \002,a7)";
+    static char fmt_1030[] = "(\002 *  DUMP=N   - RESTART FILE WRITTEN EVER"
+	    "Y\002,g11.3,\002 \002,a7)";
+    static char fmt_1040[] = "(\002 *  1SCF     - DO 1 SCF AND THEN STOP "
+	    "\002)";
+    static char fmt_1060[] = "(\002 * C.I.=(N,M)-\002,i2,\002 DOUBLY FILLED "
+	    "LEVELS USED IN A \002,/,\002 *             C.I. INVOLVING \002,i"
+	    "2,\002 M.O.'S\002)";
+    static char fmt_1050[] = "(\002 *  C.I.=N   -\002,i2,\002 M.O.S TO BE US"
+	    "ED IN C.I.\002)";
+    static char fmt_1070[] = "(\002 *  FORCE    - FORCE CALCULATION SPECIF"
+	    "IED\002)";
+    static char fmt_70[] = "(\002 *  EF       - USE EF ROUTINE FOR MINIMUM S"
+	    "EARCH\002)";
+    static char fmt_80[] = "(\002 *  TS       - USE EF ROUTINE FOR TS SEARC"
+	    "H\002)";
+    static char fmt_1080[] = "(\002 *  MINDO/3  - THE MINDO/3 HAMILTONIAN TO"
+	    " BE USED\002)";
+    static char fmt_1090[] = "(\002 *  AM1      - THE AM1 HAMILTONIAN TO BE "
+	    "USED\002)";
+    static char fmt_1100[] = "(\002 *  PM3      - THE PM3 HAMILTONIAN TO BE "
+	    "USED\002)";
+    static char fmt_1120[] = "(\002 *  OLDGEO   - PREVIOUS GEOMETRY TO BE US"
+	    "ED\002)";
+    static char fmt_1110[] = "(\002 *  PRECISE  - CRITERIA TO BE INCREASED B"
+	    "Y 100 TIMES\002)";
+    static char fmt_1130[] = "(\002 *  NOINTER  - INTERATOMIC DISTANCES NOT "
+	    "TO BE PRINTED\002)";
+    static char fmt_1140[] = "(\002 *  ISOTOPE  - FORCE MATRIX WRITTEN TO DI"
+	    "SK (CHAN. 9 )\002)";
+    static char fmt_1150[] = "(\002 *  DENOUT   - DENSITY MATRIX OUTPUT ON C"
+	    "HANNEL 10\002)";
+    static char fmt_1160[] = "(\002 *  SHIFT    - A DAMPING FACTOR OF\002,f8"
+	    ".2,\002 DEFINED\002)";
+    static char fmt_1170[] = "(\002 *  OLDENS   - INITIAL DENSITY MATRIX REA"
+	    "D OF DISK\002)";
+    static char fmt_1180[] = "(\002 *  SCFCRT   - DEFAULT SCF CRITERION REPL"
+	    "ACED BY\002,g12.3)";
+    static char fmt_1190[] = "(\002 *  ENPART   - ENERGY TO BE PARTITIONED I"
+	    "NTO COMPONENTS\002)";
+    static char fmt_1200[] = "(\002 *  NOXYZ    - CARTESIAN COORDINATES NOT "
+	    "TO BE PRINTED\002)";
+    static char fmt_1210[] = "(\002 *  SIGMA    - GEOMETRY TO BE OPTIMIZED U"
+	    "SING SIGMA.\002)";
+    static char fmt_1220[] = "(\002 *  NLLSQ    - GRADIENTS TO BE MINIMIZED "
+	    "USING NLLSQ.\002)";
+    static char fmt_1230[] = "(\002 *  ROOT     - IN A C.I. CALCULATION, R"
+	    "OOT\002,i2,\002 TO BE OPTIMIZED.\002)";
+    static char fmt_1250[] = "(\002 *  TRANS=   - \002,i4,\002 VIBRATIONS AR"
+	    "E TO BE DELETED FROM\002,\002 THE THERMO CALCULATION\002)";
+    static char fmt_1240[] = "(\002 *  TRANS    - THE REACTION VIBRATION TO "
+	    "BE DELETED FROM\002,\002 THE THERMO CALCULATION\002)";
+    static char fmt_1260[] = "(\002 *  SADDLE   - TRANSITION STATE TO BE OPT"
+	    "IMIZED\002)";
+    static char fmt_1270[] = "(\002 *   LET     - OVERRIDE SOME SAFETY CHE"
+	    "CKS\002)";
+    static char fmt_1280[] = "(\002 *  COMPFG   - PRINT HEAT OF FORMATION CA"
+	    "LC'D IN COMPFG\002)";
+    static char fmt_1290[] = "(\002 *  GNORM=   - EXIT WHEN GRADIENT NORM DR"
+	    "OPS BELOW \002,g8.3)";
+    static char fmt_1300[] = "(\002 *  PULAY    - PULAY'S METHOD TO BE USED "
+	    "IN SCF\002)";
+    static char fmt_1310[] = "(\002 *  STEP1    - FIRST  STEP-SIZE IN GRID "
+	    "=\002,f7.2)";
+    static char fmt_1320[] = "(\002 *  STEP2    - SECOND STEP-SIZE IN GRID "
+	    "=\002,f7.2)";
+    static char fmt_1500[] = "(\002 *  STEP     - STEP-SIZE IN PATH=\002,f7."
+	    "3)";
+    static char fmt_1330[] = "(\002 *  POINT1   - NUMBER OF ROWS IN GRID "
+	    "=\002,i3)";
+    static char fmt_1340[] = "(\002 *  POINT2   - NUMBER OF COLUMNS IN GRI"
+	    "D =\002,i3)";
     static char fmt_1350[] = "(\002 *  MAX      - GRID SIZE 23*23 \002)";
-    static char fmt_1510[] = "(\002 *  POINT    - NUMBER OF POINTS IN PATH\
-=\002,i3)";
-    static char fmt_1360[] = "(\002 *  BAR=     - REDUCE BAR LENGTH BY A MAX\
-. OF\002,f7.2)";
-    static char fmt_1370[] = "(\002 *  CAMP,KING- THE CAMP-KING CONVERGER TO\
- BE USED\002)";
-    static char fmt_1380[] = "(\002 *  EIGS     - PRINT ALL EIGENVALUES IN I\
-TER\002)";
-    static char fmt_1390[] = "(\002 *  EIGINV   - USE HESSIAN EIGENVALUE REV\
-ERSION IN EF\002)";
-    static char fmt_1400[] = "(\002 *  NONR     - DO NOT USE NEWTON-RAPHSON \
-STEP IN EF\002)";
-    static char fmt_1410[] = "(\002 *  ORIDE    - UNCONDITIONALLY, USE CALCU\
-LATED LAMDAS IN\002//\002 EF\002)";
-    static char fmt_1420[] = "(\002 *  HYPERFINE- HYPERFINE COUPLING CONSTAN\
-TS TO BE\002,\002 PRINTED\002)";
-    static char fmt_1430[] = "(\002 *   PL      - MONITOR CONVERGANCE IN DEN\
-SITY MATRIX\002)";
-    static char fmt_1440[] = "(\002 *  FILL=    - IN RHF CLOSED SHELL, FORCE\
- M.O.\002,i3,\002 TO BE FILLED\002)";
-    static char fmt_1470[] = "(\002 *  ITRY=    - DO A MAXIMUM OF\002,i6,\
-\002 ITERATIONS FOR SCF\002)";
-    static char fmt_1490[] = "(\002 *  0SCF     - AFTER READING AND PRINTING\
- DATA, STOP\002)";
+    static char fmt_1510[] = "(\002 *  POINT    - NUMBER OF POINTS IN PATH"
+	    "=\002,i3)";
+    static char fmt_1360[] = "(\002 *  BAR=     - REDUCE BAR LENGTH BY A MAX"
+	    ". OF\002,f7.2)";
+    static char fmt_1370[] = "(\002 *  CAMP,KING- THE CAMP-KING CONVERGER TO"
+	    " BE USED\002)";
+    static char fmt_1380[] = "(\002 *  EIGS     - PRINT ALL EIGENVALUES IN I"
+	    "TER\002)";
+    static char fmt_1390[] = "(\002 *  EIGINV   - USE HESSIAN EIGENVALUE REV"
+	    "ERSION IN EF\002)";
+    static char fmt_1400[] = "(\002 *  NONR     - DO NOT USE NEWTON-RAPHSON "
+	    "STEP IN EF\002)";
+    static char fmt_1410[] = "(\002 *  ORIDE    - UNCONDITIONALLY, USE CALCU"
+	    "LATED LAMDAS IN\002//\002 EF\002)";
+    static char fmt_1420[] = "(\002 *  HYPERFINE- HYPERFINE COUPLING CONSTAN"
+	    "TS TO BE\002,\002 PRINTED\002)";
+    static char fmt_1430[] = "(\002 *   PL      - MONITOR CONVERGANCE IN DEN"
+	    "SITY MATRIX\002)";
+    static char fmt_1440[] = "(\002 *  FILL=    - IN RHF CLOSED SHELL, FORCE"
+	    " M.O.\002,i3,\002 TO BE FILLED\002)";
+    static char fmt_1470[] = "(\002 *  ITRY=    - DO A MAXIMUM OF\002,i6,"
+	    "\002 ITERATIONS FOR SCF\002)";
+    static char fmt_1490[] = "(\002 *  0SCF     - AFTER READING AND PRINTING"
+	    " DATA, STOP\002)";
     static char fmt_1480[] = "(//10x,\002 IMPOSSIBLE OPTION REQUESTED,\002)";
-    static char fmt_1445[] = "(\002 *  FIELD    - APPLY A STATIC ELECTRIC FI\
-ELD\002)";
-    static char fmt_1450[] = "(\002 *  THERMO   - THERMODYNAMIC QUANTITIES T\
-O BE CALCULATED\002)";
-    static char fmt_1460[] = "(\002 *  ROT      - SYMMETRY NUMBER OF\002,i3\
-,\002 SPECIFIED\002)";
+    static char fmt_1445[] = "(\002 *  FIELD    - APPLY A STATIC ELECTRIC FI"
+	    "ELD\002)";
+    static char fmt_1450[] = "(\002 *  THERMO   - THERMODYNAMIC QUANTITIES T"
+	    "O BE CALCULATED\002)";
+    static char fmt_1460[] = "(\002 *  ROT      - SYMMETRY NUMBER OF\002,i3"
+	    ",\002 SPECIFIED\002)";
 
     /* System generated locals */
     integer i__1, i__2, i__3, i__4;
     doublereal d__1;
 
     /* Builtin functions */
-    /* Subroutine */ int s_copy();
-    integer s_wsfe(), e_wsfe(), i_indx(), do_fio(), i_dnnt();
-    /* Subroutine */ int s_stop();
-    integer s_cmp();
+    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
+    integer s_wsfe(cilist *), e_wsfe(void), i_indx(char *, char *, ftnlen, 
+	    ftnlen), do_fio(integer *, char *, ftnlen), i_dnnt(doublereal *);
+    /* Subroutine */ int s_stop(char *, ftnlen);
+    integer s_cmp(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
-    static logical exci;
-    static doublereal time;
-    static logical trip;
-    static integer i__, j;
-    extern doublereal reada_();
-    static integer l;
-    static logical birad;
-    static integer ielec;
+    static integer i__, j, l;
     static char ch[1];
     static logical ci;
-    static integer ii, ip, maxgeo;
+    static integer ii, ip, ip1, ip2;
+    static logical uhf, exci;
+    static doublereal time;
+    static logical trip;
+    extern doublereal reada_(char *, integer *, ftnlen);
+    static logical birad;
+    static integer ielec, maxgeo;
     static char allkey[241];
     static integer ilevel, method;
     static char chrono[7];
-    static integer ip1, ip2;
-    extern logical myword_();
-    static logical uhf;
+    extern logical myword_(char *, char *, ftnlen, ftnlen);
 
     /* Fortran I/O blocks */
-    static cilist io___7 = { 0, 6, 0, "(10X,' MOPAC - A GENERAL MOLECULAR OR\
-BITAL PACKAGE',/         ,10X,'   ORIGINAL VERSION WRITTEN IN 1983')", 0 };
-    static cilist io___8 = { 0, 6, 0, "(10X,'     BY JAMES J. P. STEWART AT \
-THE',/                  ,10X,'     UNIVERSITY OF TEXAS AT AUSTIN',/         \
-            ,10X,'          AUSTIN, TEXAS, 78712')", 0 };
+    static cilist io___7 = { 0, 6, 0, "(10X,' MOPAC - A GENERAL MOLECULAR OR"
+	    "BITAL PACKAGE',/         ,10X,'   ORIGINAL VERSION WRITTEN IN 19"
+	    "83')", 0 };
+    static cilist io___8 = { 0, 6, 0, "(10X,'     BY JAMES J. P. STEWART AT "
+	    "THE',/                  ,10X,'     UNIVERSITY OF TEXAS AT AUSTIN"
+	    "',/                     ,10X,'          AUSTIN, TEXAS, 78712')", 
+	    0 };
     static cilist io___9 = { 0, 6, 0, fmt_210, 0 };
     static cilist io___11 = { 0, 6, 0, fmt_220, 0 };
     static cilist io___13 = { 0, 6, 0, fmt_230, 0 };
@@ -454,12 +452,12 @@ THE',/                  ,10X,'     UNIVERSITY OF TEXAS AT AUSTIN',/         \
     static cilist io___103 = { 0, 6, 0, fmt_972, 0 };
     static cilist io___104 = { 0, 6, 0, fmt_973, 0 };
     static cilist io___105 = { 0, 6, 0, fmt_974, 0 };
-    static cilist io___106 = { 0, 6, 0, "(//,10X,'RMAT MUST BE SPECIFIED WIT\
-H ',                'GROUP')", 0 };
-    static cilist io___107 = { 0, 6, 0, "(//,10X,'IPO MUST BE SPECIFIED WITH\
- ',                 'GROUP')", 0 };
-    static cilist io___108 = { 0, 6, 0, "(//,10X,'NODEGEN MUST BE SPECIFIED \
-WITH ',             'GROUP')", 0 };
+    static cilist io___106 = { 0, 6, 0, "(//,10X,'RMAT MUST BE SPECIFIED WIT"
+	    "H ',                'GROUP')", 0 };
+    static cilist io___107 = { 0, 6, 0, "(//,10X,'IPO MUST BE SPECIFIED WITH"
+	    " ',                 'GROUP')", 0 };
+    static cilist io___108 = { 0, 6, 0, "(//,10X,'NODEGEN MUST BE SPECIFIED "
+	    "WITH ',             'GROUP')", 0 };
     static cilist io___111 = { 0, 6, 0, fmt_990, 0 };
     static cilist io___112 = { 0, 6, 0, fmt_980, 0 };
     static cilist io___113 = { 0, 6, 0, fmt_540, 0 };
@@ -521,37 +519,40 @@ WITH ',             'GROUP')", 0 };
     static cilist io___177 = { 0, 6, 0, fmt_1440, 0 };
     static cilist io___178 = { 0, 6, 0, fmt_1470, 0 };
     static cilist io___179 = { 0, 6, 0, fmt_1490, 0 };
-    static cilist io___180 = { 0, 6, 0, "(//10X,                            \
-                ' UHF USED WITH EITHER BIRAD, EXCITED OR C.I. ')", 0 };
+    static cilist io___180 = { 0, 6, 0, "(//10X,                            "
+	    "                ' UHF USED WITH EITHER BIRAD, EXCITED OR C.I. ')",
+	     0 };
     static cilist io___181 = { 0, 6, 0, fmt_1480, 0 };
     static cilist io___182 = { 0, 6, 0, "(//10X,' EXCITED USED WITH TRIPLET')"
 	    , 0 };
     static cilist io___183 = { 0, 6, 0, fmt_1480, 0 };
     static cilist io___184 = { 0, 6, 0, "(//10X,'T-PRIO AND NO DRC')", 0 };
     static cilist io___185 = { 0, 6, 0, fmt_1480, 0 };
-    static cilist io___186 = { 0, 6, 0, "(//10X,                            \
-                   ' ONLY ONE OF MINDO, MNDO, AM1 AND PM3 ALLOWED')", 0 };
+    static cilist io___186 = { 0, 6, 0, "(//10X,                            "
+	    "                   ' ONLY ONE OF MINDO, MNDO, AM1 AND PM3 ALLOWE"
+	    "D')", 0 };
     static cilist io___187 = { 0, 6, 0, fmt_1480, 0 };
     static cilist io___188 = { 0, 6, 0, fmt_1445, 0 };
     static cilist io___189 = { 0, 6, 0, fmt_1450, 0 };
     static cilist io___190 = { 0, 6, 0, fmt_1460, 0 };
-    static cilist io___191 = { 0, 6, 0, "                                   \
-                    (//10X,' YOU MUST SUPPLY THE SYMMETRY NUMBER \"ROT\"')", 
-	    0 };
-    static cilist io___192 = { 0, 6, 0, "(//10X,'MORE THAN ONE GEOMETRY OPTI\
-ON HAS BEEN ',   'SPECIFIED',/10X,                                          \
-     'CONFLICT MUST BE RESOLVED BEFORE JOB WILL RUN')", 0 };
+    static cilist io___191 = { 0, 6, 0, "                                   "
+	    "                    (//10X,' YOU MUST SUPPLY THE SYMMETRY NUMBER "
+	    "\"ROT\"')", 0 };
+    static cilist io___192 = { 0, 6, 0, "(//10X,'MORE THAN ONE GEOMETRY OPTI"
+	    "ON HAS BEEN ',   'SPECIFIED',/10X,                              "
+	    "                 'CONFLICT MUST BE RESOLVED BEFORE JOB WILL RUN')"
+	    , 0 };
     static cilist io___193 = { 0, 6, 0, "(A)", 0 };
     static cilist io___195 = { 0, 6, 0, "(' *  DEBUG KEYWORDS USED:  ',A)", 0 
 	    };
-    static cilist io___196 = { 0, 6, 0, "(///10X,'UNRECOGNIZED KEY-WORDS: ('\
-,A,')')", 0 };
-    static cilist io___197 = { 0, 6, 0, "(///10X,'CALCULATION STOPPED TO AVO\
-ID WASTING TIME.')", 0 };
-    static cilist io___198 = { 0, 6, 0, "(///10X,'IF THESE ARE DEBUG KEYWORD\
-S, ADD THE KEYWORD \"DEBUG\"')", 0 };
-    static cilist io___199 = { 0, 6, 0, "(//10X,' CALCULATION ABANDONED, SOR\
-RY!')", 0 };
+    static cilist io___196 = { 0, 6, 0, "(///10X,'UNRECOGNIZED KEY-WORDS: ('"
+	    ",A,')')", 0 };
+    static cilist io___197 = { 0, 6, 0, "(///10X,'CALCULATION STOPPED TO AVO"
+	    "ID WASTING TIME.')", 0 };
+    static cilist io___198 = { 0, 6, 0, "(///10X,'IF THESE ARE DEBUG KEYWORD"
+	    "S, ADD THE KEYWORD \"DEBUG\"')", 0 };
+    static cilist io___199 = { 0, 6, 0, "(//10X,' CALCULATION ABANDONED, SOR"
+	    "RY!')", 0 };
 
 
 /* COMDECK SIZES */
@@ -1567,18 +1568,17 @@ L60:
 /*     KEYWORDS ADDED FOR ESP MOPAC */
 
 /* L880: */
+    return 0;
 } /* wrtkey_ */
 
-logical myword_(keywrd, testwd, keywrd_len, testwd_len)
-char *keywrd, *testwd;
-ftnlen keywrd_len;
-ftnlen testwd_len;
+logical myword_(char *keywrd, char *testwd, ftnlen keywrd_len, ftnlen 
+	testwd_len)
 {
     /* System generated locals */
     logical ret_val;
 
     /* Builtin functions */
-    integer i_indx();
+    integer i_indx(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
     static integer j, k;
